==> xxdiff-1.12.tar.gz: xxdiff-1.12/src/diffs.inline.h <==
/******************************************************************************\
 * $Id: diffs.inline.h,v 1.2 2001/05/20 18:08:45 blais Exp $
 * $Date: 2001/05/20 18:08:45 $
 *
 * Copyright (C) 1999-2001  Martin Blais <blais@iro.umontreal.ca>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *****************************************************************************/

/*==============================================================================
 * EXTERNAL DECLARATIONS
 *============================================================================*/


XX_NAMESPACE_BEGIN


/*==============================================================================
 * CLASS XxDiffs
 *============================================================================*/

//------------------------------------------------------------------------------
//
inline uint XxDiffs::getNbLines() const
{
   return _lines.size();
}

//------------------------------------------------------------------------------
//
inline const XxLine& XxDiffs::getLine( const XxDln lineno ) const
{
   XX_ASSERT( lineno > 0 && lineno <= XxDln(_lines.size()) );
   return _lines[ lineno - 1 ];
}

//------------------------------------------------------------------------------
//
inline XxLine& XxDiffs::getLineNC( const XxDln lineno )
{
   XX_ASSERT( lineno > 0 && lineno <= XxDln(_lines.size()) );
   return _lines[ lineno - 1 ];
}

//------------------------------------------------------------------------------
//
inline void XxDiffs::clearDirty()
{
   _dirty = false;
}

//------------------------------------------------------------------------------
//
inline bool XxDiffs::isDirty() const
{
   return _dirty;
}

//------------------------------------------------------------------------------
//
inline bool XxDiffs::isDirectoryDiff() const
{
   return _isDirectoryDiff;
}

XX_NAMESPACE_END

==> xxdiff_2.5.orig.tar.gz: xxdiff-2.5/src/diffs.inline.h <==
/******************************************************************************\
 * $Id: diffs.inline.h,v 1.6 2002/02/23 17:43:56 blais Exp $
 * $Date: 2002/02/23 17:43:56 $
 *
 * Copyright (C) 1999-2001  Martin Blais <blais@iro.umontreal.ca>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 ******************************************************************************/

/*==============================================================================
 * EXTERNAL DECLARATIONS
 *============================================================================*/


XX_NAMESPACE_BEGIN


/*==============================================================================
 * CLASS XxDiffs
 *============================================================================*/

//------------------------------------------------------------------------------
//
inline XxDln XxDiffs::getNbLines() const
{
   return _lines.size() - 1;
}

//------------------------------------------------------------------------------
//
inline const XxLine& XxDiffs::getLine( const XxDln lineno ) const
{
#ifdef XX_DEBUG
   if ( !( lineno > 0 && lineno <= getNbLines() ) ) {
      XX_TRACE( lineno );
   }
#endif
   XX_CHECK( lineno > 0 && lineno <= getNbLines() );
   return _lines[ lineno ];
}

//------------------------------------------------------------------------------
//
inline XxLine& XxDiffs::getLineNC( const XxDln lineno )
{
   XX_CHECK( lineno > 0 && lineno <= getNbLines() );
   return _lines[ lineno ];
}

//------------------------------------------------------------------------------
//
inline void XxDiffs::clearDirty()
{
   _dirty = false;
}

//------------------------------------------------------------------------------
//
inline bool XxDiffs::isDirty() const
{
   return _dirty;
}

//------------------------------------------------------------------------------
//
inline bool XxDiffs::isDirectoryDiff() const
{
   return _isDirectoryDiff;
}

XX_NAMESPACE_END
